/************************************************************************
*                                                                       *
*   Filename:      MC_L1-Flash_LED-20p-PCL.c                            *
*   Date:          9/8/08                                               *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: delay.h, delay.c    : provides DelayMs()            *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 1, example 2                                 *
*                                                                       *
*   Flashes an LED at approx 1 Hz, with 20% duty cycle                  *
*   LED continues to flash until power is removed.                      *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

#define XTAL_FREQ   4MHZ     // oscillator frequency for DelayMs()
#include "delay.h"           // defines DelayMs()

// Config: ext reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    // Initialisation
    TRISIO = ~(1<<1);           // configure GP1 (only) as an output

    // Main loop
    for (;;) {
        // turn on LED on GP1
        GPIO1 = 1;              

        // stay on for 200ms
        DelayMs(200);  
                 
        // turn off LED on GP1
        GPIO1 = 0;              

        // stay off for 800ms
        DelayMs(250);           
        DelayMs(250);
        DelayMs(250);
        DelayMs(50);
        
    }   // repeat forever
}
