/************************************************************************
*                                                                       *
*   Filename:      MC_L1-Flash_LED-50p-PCL.c                            *
*   Date:          10/8/08                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: delay.h, delay.c    : provides DelayMs()            *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 1, example 3                                 *
*                                                                       *
*   Flashes a LED at approx 1 Hz.                                       *
*   LED continues to flash until power is removed.                      *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

#define XTAL_FREQ   4MHZ     // oscillator frequency for DelayMs()
#include "delay.h"           // defines DelayMs()

// Config: ext reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO = 0;  // shadow copy of GPIO

    // Initialisation
    TRISIO = ~(1<<1);           // configure GP1 (only) as an output

    // Main loop
    for (;;) {
        // toggle GP1
        sGPIO ^= 1<<1;          // flip shadow bit corresponding to GP1
        GPIO = sGPIO;           // write to GPIO

        // delay 500 ms
        DelayMs(250);           // delay 500ms
        DelayMs(250);
        
    }   // repeat forever
}
