/************************************************************************
*                                                                       *
*   Filename:      MC_L1-Toggle_LED-HTC.c                               *
*   Date:          10/8/08                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 1, example 5                                 *
*                                                                       *
*   Toggles LED when pushbutton is pressed (low) then released (high)   *
*   Uses counting algorithm to debounce switch                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - indicator LED                                             *
*       GP3 - pushbutton switch                                         *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for _delay()

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO;          // shadow copy of GPIO
    unsigned char   db_cnt;         // debounce counter

    // Initialisation
    GPIO = 0;                       // start with LED off
    sGPIO = 0;                      //   update shadow
    TRISIO = ~(1<<1);               // configure GP1 (only) as an output

    // Main loop
    for (;;) {
        // wait until button pressed (GP3 low), debounce by counting:
        for (db_cnt = 0; db_cnt <= 10; db_cnt++) {
            __delay_ms(1);          // sample every 1 ms
            if (GPIO3 == 1)         // if button up (GP3 high)
                db_cnt = 0;         //   restart count
        }                           // until button down for 10 successive reads

        // toggle LED on GP1
        sGPIO ^= 1<<1;              // flip shadow GP1
        GPIO = sGPIO;               // write to GPIO

        // wait until button released (GP3 high), debounce by counting:
        for (db_cnt = 0; db_cnt <= 10; db_cnt++) {
            __delay_ms(1);          // sample every 1 ms
            if (GPIO3 == 0)         // if button down (GP3 low)
                db_cnt = 0;         //   restart count
        }                           // until button up for 10 successive reads

    }   // repeat forever
}
