/************************************************************************
*                                                                       *
*   Filename:      MC_L2-Flash+PB_LED-HTC                               *
*   Date:          23/12/08                                             *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 2, example 2                                 *
*                                                                       *
*   Demonstrates use of Timer0 to maintain timing of background actions *
*   while performing other actions in response to changing inputs       *
*                                                                       *
*   One LED simply flashes at 1 Hz (50% duty cycle).                    *
*   The other LED is only lit when the pushbutton is pressed            *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - "button pressed" indicator LED                            *
*       GP2 - flashing LED                                              *
*       GP3 - pushbutton                                                *
*                                                                       *
************************************************************************/

#include <htc.h>

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO;          // shadow copy of GPIO
    unsigned char   dc;             // delay counter

    // Initialisation
    GPIO = 0;                       // start with all LEDs off
    sGPIO = 0;                      //   update shadow
    TRISIO = 0b111001;              // configure GP1 and GP2 as outputs
    OPTION = 0b11010100;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----100                 prescale = 32 (PS = 100)
             //                         -> increment every 32 us
                 
    // Main loop  
    for (;;) {
        // delay 500ms while checking for button press
        for (dc = 0; dc < 125; dc++) {  // repeat for 500ms (125 x 4ms = 500ms)
            TMR0 = 0;                       // clear timer0
            while (TMR0 < 125) {            // repeat for 4ms (125 x 32us)
                sGPIO &= ~(1<<1);               // assume button up -> LED off
                if (GPIO3 == 0)                 // if button pressed (GP3 low)
                    sGPIO |= 1<<1;              //   turn on LED on GP1

                GPIO = sGPIO;                   // update GPIO
            }
        }
        // toggle LED on GP2
        sGPIO ^= 1<<2;                  
                
    }   // repeat forever
}
