/************************************************************************
*                                                                       *
*   Filename:      MC_L2-Flash_LED_XTAL-HTC.c                           *
*   Date:          4/7/09                                               *
*   File Version:  1.2                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C Pro v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 2, example 4                                 *
*                                                                       *
*   Demonstrates use of Timer0 in counter mode                          *
*                                                                       *
*   LED flashes at 1 Hz (50% duty cycle),                               *
*   with timing derived from 32.768 kHz input on T0CKI                  *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*       T0CKI - 32.768 kHz signal                                       *
*                                                                       *
************************************************************************/

#include <htc.h>

// Config: ext reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO;          // shadow copy of GPIO

    // Initialisation
    TRISIO = ~(1<<1);               // configure GP1 (only) as an output
    OPTION = 0b11110110;            // configure Timer0:
             //--1-----                 counter mode (T0CS = 1)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----110                 prescale = 128 (PS = 110)
             //                         -> increment at 256 Hz with 32.768 kHz input
                    
     // Main loop
    for (;;)
    {
        // TMR0<7> cycles at 1Hz so continually copy to GP1
        sGPIO = 0;                  // assume TMR<7>=0 -> LED off (shadow)
        if (TMR0 & 1<<7)            // if TMR0<7>=1
            sGPIO |= 1<<1;          //   turn on LED (shadow)
        
        GPIO = sGPIO;               // copy shadow to GPIO
        
    }   // repeat forever
}

