/************************************************************************
*                                                                       *
*   Filename:      MC_L2-Reaction_timer-HTC.c                           *
*   Date:          8/10/08                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 2, example 1                                 *
*                   Reaction Timer game.                                *
*                                                                       *
*   User must attempt to press button within defined reaction time      *
*   after "start" LED lights.  Success is indicated by "success" LED.   *
*                                                                       *
*       Starts with both LEDs unlit.                                    *
*       2 sec delay before lighting "start"                             *
*       Waits up to 1 sec for button press                              *
*       (only) on button press, lights "success"                        *
*       1 sec delay before repeating from start                         *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for _delay()


/***** CONSTANTS *****/
#define MAXRT   200             // Maximum reaction time in ms


/***** CONFIGURATION *****/

// Pin assignments
#define START   GPIO2           // LEDs
#define SUCCESS GPIO1

#define BUTTON  GPIO3           // switches

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


/***** MACROS *****/

// Delay in seconds
//   Max delay is 25.5 sec 
//   Calls: DelayMs() (defined in delay.h)
#define DelayS(T) {unsigned char i; for (i=0; i<T*10; i++) __delay_ms(100);}


/***** MAIN PROGRAM *****/
void main()
{
    unsigned char   cnt8ms;         // 8ms counter (incremented every 8ms)

    // Initialisation
    TRISIO = 0b111001;              // configure GP1 and GP2 as outputs
    OPTION = 0b11010100;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----100                 prescale = 32 (PS = 100)
             //                         -> increment every 32 us
             
    // Main loop                                
    for (;;) {
        GPIO = 0;                   // start with all LEDs off

        DelayS(2);                  // delay 2s
 
        START = 1;                  // turn on start LED

        // wait up to 1 sec for button press
        cnt8ms = 0;
        while (BUTTON == 1 && cnt8ms < 1000/8) {
            TMR0 = 0;               // clear timer0
            while (TMR0 < 8000/32)  // wait for 8ms (32us/tick)
                ;
            ++cnt8ms;               // increment 8ms counter
        }
        // check elapsed time
        if (cnt8ms < MAXRT/8)       // if time < max reaction time (8ms/count)
            SUCCESS = 1;            //   turn on success LED

        DelayS(1);                  // delay 1s
    
    }   // repeat forever
}
