/************************************************************************
*                                                                       *
*   Filename:      MC_L2-Timer_debounce-PCL.c                           *
*   Date:          21/10/08                                             *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 2, example 3a                                *
*                                                                       *
*   Demonstrates use of Timer0 to implement debounce counting algorithm *
*                                                                       *
*   Toggles LED when pushbutton is pressed (low) then released (high)   *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - on/off indicator LED                                      *
*       GP3 - pushbutton switch                                         *
*                                                                       *
************************************************************************/

#include <htc.h>

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO;              // shadow copy of GPIO

    // Initialisation
    GPIO = 0;                           // start with LED off
    sGPIO = 0;                          //   update shadow
    TRISIO = 0b111101;                  // configure GP1 (only) as an output
    OPTION = 0b11010101;                // configure Timer0:
             //--0-----                     timer mode (T0CS = 0)
             //----0---                     prescaler assigned to Timer0 (PSA = 0)
             //-----101                     prescale = 64 (PS = 101)
             //                             -> increment every 64 us
             
    // Main loop
    for (;;) {
        // wait until button pressed (GP3 low), debounce using timer0:
        TMR0 = 0;                       // reset timer
        while (TMR0 < 157)              // wait at least 10ms (157 x 64us = 10ms)
            if (GPIO3 == 1)             //   if button up,
                TMR0 = 0;               //     restart wait
        
        // toggle LED on GP1
        sGPIO ^= 1<<1;                  // flip shadow GP1
        GPIO = sGPIO;                   // write to GPIO

        // wait until button released (GP3 high), debounce using timer0:
        TMR0 = 0;                       // reset timer
        while (TMR0 < 157)              // wait at least 10ms (157 x 64us = 10ms)
            if (GPIO3 == 0)             //   if button down,
                TMR0 = 0;               //     restart wait
            
    }   // repeat forever
}
