/************************************************************************
*                                                                       *
*   Filename:      MC_L2-Timer_macro_debounce-HTC.c                     *
*   Date:          21/10/08                                             *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros.h     (provides debounce macros)          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 2, example 3b                                *
*                                                                       *
*   Demonstrates use of Timer0-based debounce macros                    *
*                                                                       *
*   Toggles LED when pushbutton is pressed (low) then released (high)   *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - on/off indicator LED                                      *
*       GP3 - pushbutton switch                                         *
*                                                                       *
************************************************************************/

#include <htc.h>

#include "stdmacros-HTC.h"  // DbnceHi() - debounce switch, wait for high
                            // DbnceLo() - debounce switch, wait for low
                            // Requires: TMR0 at 256us/tick

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, 4MHz int clock
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);


void main()
{
    unsigned char   sGPIO;          // shadow copy of GPIO

    // Initialisation
    GPIO = 0;                       // start with LED off
    sGPIO = 0;                      //   update shadow
    TRISIO = ~(1<<1);               // configure GP1 (only) as an output
    OPTION = 0b11010111;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----111                 prescale = 256 (PS = 111)
             //                         -> increment every 256 us
                 
    // Main loop
    for (;;) {
        // wait until button pressed (GP3 low)
        DbnceLo(GPIO3);
        
        // toggle LED on GP1
        sGPIO ^= 1<<1;              // flip shadow GP1
        GPIO = sGPIO;               // write to GPIO

        // wait until button released (GP3 high)
        DbnceHi(GPIO3);
            
    }   // repeat forever
}
