/************************************************************************
*                                                                       *
*   Filename:      MC_L3-Flash_LED-50p-int-fast-HTC.c                   *
*   Date:          4/7/09                                               *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 3, example 1a                                *
*                                                                       *
*   Demonstrates use of Timer0 interrupt to perform a background task   *
*                                                                       *
*   Flash LED at approx 7.6 Hz (50% duty cycle)                         *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP2 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

/***** CONFIGURATION *****/
//      ext reset, no code or data protect, no brownout detect,
//      no watchdog, power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);

// Pin assignments
#define nLED    2               // flashing LED on GP2


/***** GLOBAL VARIABLES *****/
unsigned char   sGPIO;          // shadow copy of GPIO


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    // setup ports
    GPIO = 0;                       // start with LED off
    sGPIO = 0;                      //   update shadow
    TRISIO = ~(1<<nLED);            // configure LED pin (only) as an output
    // setup Timer0
    OPTION = 0b11010111;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----111                 prescale = 256 (PS = 111)
                                    //  -> increment every 256 us
    // configure interrupts
    T0IE = 1;                       // enable Timer0 interrupt
    ei();                           // enable global interrupts
                                    
    // Main loop
    for (;;) {
        // continually copy shadow GPIO to port
        GPIO = sGPIO; 
            
    }   // repeat forever
}


/***** INTERRUPT SERVICE ROUTINE *****/
void interrupt isr(void)
{
    // handle Timer0 interrupt
    T0IF = 0;                       // clear interrupt flag
    
    // toggle LED
    sGPIO ^= 1<<nLED;               // only update shadow register
}
