/************************************************************************
*                                                                       *
*   Filename:      MC_L3-Toggle_LED-ext_int-HTC.c                       *
*   Date:          5/7/09                                               *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 3, example 5                                 *
*                                                                       *
*   Demonstrates use of external interrupt (INT pin)                    *
*                                                                       *
*   Toggles LED on GP1                                                  *
*   when pushbutton on INT is pressed (high -> low transition)          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - indicator LED                                             *
*       INT - pushbutton (active low)                                   *
*                                                                       *
************************************************************************/

#include <htc.h>

/***** CONFIGURATION *****/
//      ext reset, no code or data protect, no brownout detect,
//      no watchdog, power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);

// Pin assignments
#define nB_LED   1              // indicator LED on GP1


/***** GLOBAL VARIABLES *****/
unsigned char   sGPIO;          // shadow copy of GPIO


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    // setup ports
    GPIO = 0;                       // start with LED off
    sGPIO = 0;                      //   update shadow
    TRISIO = ~(1<<nB_LED);          // configure LED pin as output
    // configure external interrupt
    INTEDG = 0;                     // trigger on falling edge 
    // configure interrupts
    INTE = 1;                       // enable external interrupt
    ei();                           // enable global interrupts
                                    
    // Main loop
    for (;;)
    {
        // continually copy shadow GPIO to port
        GPIO = sGPIO; 
            
    }   // repeat forever
}


/***** INTERRUPT SERVICE ROUTINE *****/
void interrupt isr(void)
{
    // Service external interrupt
    //   Triggered on high -> low transition on INT pin
    //   caused by externally debounced pushbutton press
    //   
    INTF = 0;                       // clear interrupt flag
    
    // toggle LED
    sGPIO ^= 1<<nB_LED;             // only update shadow register
}
