/************************************************************************
*                                                                       *
*   Filename:      MC_L4-WDTdemo+LED-HTC.c                              *
*   Date:          11/4/09                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C Pro v9.60PL5 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros-HTC.h     : provides DelayS()             *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 4, example 5a                                *
*                                                                       *
*   Demonstrates watchdog timer                                         *
*       plus differentiation of WDT time-out from POR reset             *
*                                                                       *
*   Turn on LED for 1s, turn off, then enter endless loop               *
*   If WDT enabled, processor resets after 2.3s                         *
*   Turns on WDT LED to indicate WDT reset                              *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - "flashing" LED                                            *
*       GP2 - WDT LED (indicates WDT time-out reset)                    *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for _delay_ms()

#include "stdmacros-HTC.h"      // DelayS() - delay in seconds


/***** CONFIGURATION *****/
#define     WATCHDOG            // define to enable watchdog timer

#ifdef WATCHDOG
    // Config: ext reset, no code or data protect, no brownout detect,
    //         watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTEN & PWRTEN & INTIO);
#else
    // Config: ext reset, no code or data protect, no brownout detect,
    //         no watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);
#endif   

// Pin assignments
#define F_LED   GPIO1           // "flashing" LED on GP1
#define nF_LED  1               //   (pin 1)
#define W_LED   GPIO2           // WDT LED to indicate WDT time-out reset
#define nW_LED  2               //   (pin 2)


/***** MAIN PROGRAM *****/
void main()
{
    /*** Initialisation ***/
    // configure port
    TRISIO = ~(1<<nF_LED|1<<nW_LED);    // configure LED pins as outputs
    
    // configure watchdog timer
    OPTION = 0b11001111;            // set WDT timeout:
             //----1---                 prescaler assigned to WDT (PSA = 1)
             //-----111                 prescale = 128 (PS = 111)
                                    //  -> WDT timeout = 2.3 s
    
    /*** Main code ***/
    if (!TO)                    // if WDT timeout has occurred,
    {
        W_LED = 1;              //   turn on "WDT" LED
    }

    F_LED = 1;                  // turn on "flash" LED
    
    DelayS(1);                  // delay 1s
   
    F_LED = 0;                  // turn off "flash" LED 
    
    for (;;)                    // wait forever
        ;
}
