/************************************************************************
*                                                                       *
*   Filename:      MC_L4-WDTdemo+clr-HTC.c                              *
*   Date:          11/4/09                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros-HTC.h     : provides DelayS()             *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 4, example 5b                                *
*                                                                       *
*   Demonstrates clearing the watchdog timer                            *
*                                                                       *
*   Turn on LED for 1s, turn off, then enter endless loop,              *
*   in which the WDT is repeatedly cleared, so LED stays off,           *
*   even if the watchdog is enabled                                     *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - indicator LED                                             *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for _delay_ms()

#include "stdmacros-HTC.h"      // DelayS() - delay in seconds


/***** CONFIGURATION *****/
#define     WATCHDOG            // define to enable watchdog timer

#ifdef WATCHDOG
    // Config: ext reset, no code or data protect, no brownout detect,
    //         watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTEN & PWRTEN & INTIO);
#else
    // Config: ext reset, no code or data protect, no brownout detect,
    //         no watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);
#endif   

// Pin assignments
#define LED     GPIO1           // indicator LED on GP1
#define n_LED   1               //   (pin 1)


/***** MAIN PROGRAM *****/
void main()
{
    /*** Initialisation ***/
    // configure port
    TRISIO = ~(1<<n_LED);           // configure LED pin (only) as output
    
    // configure watchdog timer
    OPTION = 0b11001111;            // set WDT timeout:
             //----1---                 prescaler assigned to WDT (PSA = 1)
             //-----111                 prescale = 128 (PS = 111)
                                    //  -> WDT timeout = 2.3 s
    
    /*** Main code ***/
    LED = 1;                    // turn on LED
    
    DelayS(1);                  // delay 1s
   
    LED = 0;                    // turn off LED 
    
    for (;;)                    // repeat forever
    {
        CLRWDT();               //   clear watchdog timer
    }
}

