/************************************************************************
*                                                                       *
*   Filename:      MC_L4-WDTsleep-PCL.c                                 *
*   Date:          11/4/09                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros-PCL.h     : provides DelayS()             *
*                   delay.h, delay.c    : required by stdmacros-PCL.h   *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 4, example 6                                 *
*                                                                       *
*   Demonstrates periodic wake from sleep, using the watchdog timer     *
*                                                                       *
*   Turn on LED for 1s, turn off, then sleep                            *
*       LED stays off if watchdog not enabled,                          *
*       flashes (1s on, 2.3s off) if WDT enabled                        *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - indicator LED                                             *
*                                                                       *
************************************************************************/

#include <htc.h>

#include "stdmacros-PCL.h"      // DelayS() - delay in seconds


/***** CONFIGURATION *****/
#define     WATCHDOG            // define to enable watchdog timer

#ifdef WATCHDOG
    // Config: ext reset, no code or data protect, no brownout detect,
    //         watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTEN & PWRTEN & INTIO);
#else
    // Config: ext reset, no code or data protect, no brownout detect,
    //         no watchdog, power-up timer enabled, 4MHz int clock
    __CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);
#endif   

// Pin assignments
#define LED     GPIO1           // indicator LED on GP1
#define n_LED   1               //   (pin 1)


/***** MAIN PROGRAM *****/
void main()
{
    /*** Initialisation ***/
    // configure port
    TRISIO = ~(1<<n_LED);           // configure LED pin (only) as output
    
    // configure watchdog timer
    OPTION = 0b11001111;            // set WDT timeout:
             //----1---                 prescaler assigned to WDT (PSA = 1)
             //-----111                 prescale = 128 (PS = 111)
                                    //  -> WDT timeout = 2.3 s
    
    /*** Main loop ***/
    for (;;)
    {
        LED = 1;                    // turn on LED
    
        DelayS(1);                  // delay 1s
   
        LED = 0;                    // turn off LED 
    
        SLEEP();                    // enter sleep mode (until WDT time-out)
    
    }   // repeat forever
}
