/************************************************************************
*                                                                       *
*   Filename:      MC_L5-Flash_LED_32k_XTAL-PCL.c                       *
*   Date:          12/7/09                                              *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 5, example 3                                 *
*                                                                       *
*   Demonstrates use of LP oscillator mode                              *
*   (using 32.768 kHz crystal)                                          *
*                                                                       *
*   LED flashes at 1Hz (50% duty cycle),                                *
*   with timing derived from 8192 Hz instruction clock                  *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, LP oscillator
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & LP);

// Pin assignments
#define nLED    1                   // flashing LED on GP1


void main()
{
    unsigned char   sGPIO;          // shadow copy of GPIO

    // Initialisation
    TRISIO = ~(1<<nLED);            // configure LED pin (only) as output
    OPTION = 0b11010100;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----100                 prescale = 32 (PS = 100)
                                    //  -> increment at 256 Hz with 8192 Hz inst clock
                
    // Main loop
    for (;;)
    {
        // TMR0<7> cycles at 1Hz, so continually copy to LED
        sGPIO = 0;                  // assume TMR<7>=0 -> LED off (shadow)
        if (TMR0 & 1<<7)            // if TMR0<7>=1
            sGPIO |= 1<<nLED;       //   turn on LED (shadow) 
        
        GPIO = sGPIO;               // copy shadow to GPIO
        
    }   // repeat forever
}
