/************************************************************************
*                                                                       *
*   Filename:      MC_L5-Flash_LED_4M_XT-HTC.c                          *
*   Date:          12/7/09                                              *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 5, example 4                                 *
*                                                                       *
*   Demonstrates use of XT oscillator mode                              *
*   (using 4 MHz crystal or resonator)                                  *
*                                                                       *
*   Flash LED at exactly 1 Hz (50% duty cycle)                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

/***** CONFIGURATION *****/
//      int reset, no code or data protect, no brownout detect,
//      no watchdog, power-up timer enabled, XT oscillator (4 MHz)
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & XT);

// Pin assignments
#define nLED    1               // flashing LED on GP1


/***** GLOBAL VARIABLES *****/
unsigned char   sGPIO;          // shadow copy of GPIO


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    // setup ports
    GPIO = 0;                       // start with LED off
    sGPIO = 0;                      //   update shadow
    TRISIO = ~(1<<nLED);            // configure LED pin (only) as an output
    // configure Timer0
    T0CS = 0;                       // select timer mode
    PSA = 1;                        // no prescaler (assigned to WDT)
                                    //  -> increment TMR0 every 1 us             
    // configure interrupts
    T0IE = 1;                       // enable Timer0 interrupt
    ei();                           // enable global interrupts
                                    
    // Main loop
    for (;;) {
        // continually copy shadow GPIO to port
        GPIO = sGPIO; 
            
    }   // repeat forever
}


/***** INTERRUPT SERVICE ROUTINE *****/
void interrupt isr(void)
{
    static unsigned int     cnt_t0 = 0;     // counts timer0 overflows
    
    // service Timer0 interrupt
    //   TMR0 overflows every 250 clocks = 250 us
    //   (only Timer0 interrupts are enabled)
    //
    TMR0 += 256-250+3;              // add value to Timer0
                                    //   for overflow after 250 counts
    T0IF = 0;                       // clear interrupt flag
    
    // toggle LED every 500 ms
    ++cnt_t0;                       // increment interrupt count (every 250 us)
    if (cnt_t0 == 500000/250) {     // if count overflow (every 500 ms),
        cnt_t0 = 0;                 //   reset count
        sGPIO ^= 1<<nLED;           //   toggle LED (using shadow register)
    }
}
