/************************************************************************
*                                                                       *
*   Filename:      MC_L5-Flash_LED_ExtRC-HTC.c                          *
*   Date:          20/5/09                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 5, example 5                                 *
*                                                                       *
*   Demonstrates use of external RC oscillator (~1 kHz)                 *
*                                                                       *
*   LED on GP1 flashes at approx 1 Hz (50% duty cycle),                 *
*   with timing derived from ~256 Hz instruction clock                  *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP1 - flashing LED                                              *
*                                                                       *
************************************************************************/

#include <htc.h>

// Config: int reset, no code protect, no brownout detect, no watchdog,
//         power-up timer enabled, ext RC oscillator (~1 kHz) + clkout
__CONFIG(MCLRDIS & UNPROTECT & BORDIS & WDTDIS & PWRTEN & RCCLK);


void main()
{
    // Initialisation
    TRISIO = ~(1<<1);               // configure GP1 (only) as an output
    OPTION = 0b11010101;            // configure Timer0:
             //--0-----                 timer mode (T0CS = 0)
             //----0---                 prescaler assigned to Timer0 (PSA = 0)
             //-----101                 prescale = 64 (PS = 101)
                                    //  -> increment at 4 Hz with 256 Hz inst clock
                
    // Main loop
    for (;;)
    {
        // TMR0<1> cycles at 1 Hz, so continually copy to GP1
        GPIO = TMR0;                // copy TMR0 to GPIO
        
    }   // repeat forever
}
