/************************************************************************
*                                                                       *
*   Filename:      MC_L5-IntRC+CLKOUT-PCL.c                             *
*   Date:          9/5/09                                               *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 5, example 1                                 *
*                                                                       *
*   Demonstrates CLKOUT function in Internal RC oscillator mode         *
*                                                                       *
*   Toggles a pin as quickly as possible                                *  
*   for comparison with 1 MHz CLKOUT signal                             *
*                                                                       *
*   Uses inline 500 ms delay routine                                    *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       GP2 - fast-changing output                                      *
*                                                                       *
************************************************************************/

#include <htc.h>


/***** CONFIGURATION *****/
// Config: ext reset, no code or data protect, brownout detect,
//         no watchdog, power-up timer enabled, 4MHz int clock with CLKOUT
__CONFIG(MCLREN & UNPROTECT & BOREN & WDTDIS & PWRTEN & INTCLK);

// Pin assignments
#define OUT     GPIO2           // fast-changing output on GP2


/***** GLOBAL VARIABLES *****/
unsigned char   sGPIO;          // shadow copy of GPIO


/***** MAIN PROGRAM *****/
void main()
{
    /*** Initialisation ***/
    // configure port
    TRISIO = 0;             // configure all pins (except GP3 and GP4) as outputs
    
    /*** Main loop ***/
    for (;;)  
    {              
        OUT = !OUT;         // toggle output pin as fast as possible
    }
}
