/************************************************************************
*                                                                       *
*   Filename:      MC_L6-Comp_2input-PCL.c                              *
*   Date:          6/9/09                                               *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: delay.h     : HI-TECH supplied delay code           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 6, example 7                                 *
*                                                                       *
*   Demonstrates comparator input multiplexing                          *
*                                                                       *
*   Turns on: LED 1 when CIN+ > 1.5 V                                   *
*         and LED 2 when CIN- > 1.5 V                                   *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       CIN+  - input 1 (LDR/resistor divider)                          *
*       CIN-  - input 2 (LDR/resistor divider)                          *
*       GP4   - indicator LED 1                                         *
*       GP5   - indicator LED 2                                         *
*                                                                       *
************************************************************************/

#include <htc.h>

#define XTAL_FREQ   4MHZ    // oscillator frequency for DelayUs()
#include "delay.h"          // defines DelayUs()


/***** CONFIGURATION *****/
//      ext reset, no code or data protect, no brownout detect,
//      no watchdog, power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);

// Pin assignments
#define nLED1   4               // indicator LED 1 on GP4
#define nLED2   5               // indicator LED 2 on GP5


/***** MAIN PROGRAM *****/
void main()
{
    unsigned char   sGPIO;      // shadow copy of GPIO
    
    // Initialisation
    TRISIO = ~(1<<nLED1|1<<nLED2);  // configure LED pins as outputs
    
    // configure comparator
    CMCON = 0b110;              // select mode 6 (CM = 110):
                                //   +ref is CVref,
                                //   -ref is CIN+ or CIN- (selected by CIS)
                                //   no external output,
                                //   comparator on
    CINV = 1;                   // inverted output 
                                // -> COUT = 1 if -ref > CVref
                                
    // configure voltage reference
    VRCON = 7;                  // select voltage: VR = 7,
    VRR = 1;                    //   low range -> CVref = 0.292*Vdd
    VREN = 1;                   // enable voltage reference
                                // -> CVref = 1.5 V (if Vdd = 5.0 V) 
    
    
    // Main loop
    for (;;)
    {
        sGPIO = 0;                  // start with both LEDs off
        
        // test input 1
        CIS = 1;                    // select CIN+ pin as -ref
        DelayUs(10);                // wait 10us to settle
        if (COUT)                   // if CIN+ > CVref
            sGPIO |= 1<<nLED1;      //   turn on LED 1
                    
        // test input 2
        CIS = 0;                    // select CIN- pin as -ref
        DelayUs(10);                // wait 10us to settle
        if (COUT)                   // if CIN- > CVref
            sGPIO |= 1<<nLED2;      //   turn on LED 2      
            
        // display test results           
        GPIO = sGPIO;               // copy shadow to GPIO port
    }
}
