/************************************************************************
*                                                                       *
*   Filename:      MC_L6-Comp_LED-intref_hyst-PCL.c                     *
*   Date:          23/8/09                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     12F629                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 6, example 3                                 *
*                                                                       *
*   Demonstrates comparator hysteresis (using COUT)                     *
*   with programmable voltage reference                                 *
*                                                                       *
*   Turns on LED when voltage on CIN+ < 1.5 V                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       CIN+  - voltage to be measured (e.g. pot output or LDR)         *
*       COUT  - comparator output (fed back to input via resistor)      *
*       GP5   - indicator LED                                           *
*                                                                       *
************************************************************************/

#include <htc.h>


/***** CONFIGURATION *****/
//      ext reset, no code or data protect, no brownout detect,
//      no watchdog, power-up timer enabled, 4MHz int clock
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO);

// Pin assignments
#define LED     GPIO5           // indicator LED on GP5
#define nLED    5               //   (port bit 5)


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    
    // configure ports
    TRISIO = ~(1<<nLED);        // configure LED pin (only) as an output
    
    // configure comparator
    CMCON = 0b101;              // select mode 5 (CM = 101):
                                //   +ref is CVref,
                                //   external output enabled,
                                //   comparator on
    CIS = 1;                    // -ref is CIN+
    CINV = 1;                   // inverted output 
                                // -> COUT = 1 if CIN+ > CVref,
                                //    COUT pin enabled
                                
    TRIS2 = 0;                  // configure COUT (GP2) as an output
                                
    // configure voltage reference
    VRCON = 7;                  // select voltage: VR = 7,
    VRR = 1;                    //   low range -> CVref = 0.292*Vdd
    VREN = 1;                   // enable voltage reference
                                // -> CVref = 1.5 V (if Vdd = 5.0 V) 
    
    // Main loop
    for (;;)
    {
        LED = !COUT;            // continually display inverse of comparator output
    }
}
