/************************************************************************
*                                                                       *
*   Filename:      MC_L7-Count_7seg_x1-HTC.c                            *
*   Date:          16/11/09                                             *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     16F684                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros-HTC.h     : provides DelayS()             *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 7, example 1a                                *
*                                                                       *
*   Demonstrates use of lookup tables to drive a 7-segment display      *
*                                                                       *
*   Single digit 7-segment display counts repeating 0 -> 9              *
*   1 second per count, with timing derived from int RC oscillator      *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       RA2, RC0-5 = 7-segment display (common cathode)                 *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for delay functions
#include "stdmacros-HTC.h"      // DelayS() - delay in seconds


/***** CONFIGURATION *****/
//  ext reset, no code or data protect, no brownout detect,
//  no watchdog, power-up timer, int clock with I/O,
//  no failsafe clock monitor, two-speed start-up disabled 
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO & FCMDIS & IESODIS);


/***** LOOKUP TABLES *****/

// Lookup pattern for 7 segment display on port A
const char pat7segA[10] = {
    // RA2 = G
    0b000000,   // 0
    0b000000,   // 1
    0b000100,   // 2
    0b000100,   // 3
    0b000100,   // 4
    0b000100,   // 5
    0b000100,   // 6
    0b000000,   // 7
    0b000100,   // 8
    0b000100    // 9
}; 

// Lookup pattern for 7 segment display on port C
const char pat7segC[10] = {
    // RC5:0 = ABCDEF
    0b111111,   // 0
    0b011000,   // 1
    0b110110,   // 2
    0b111100,   // 3
    0b011001,   // 4
    0b101101,   // 5
    0b101111,   // 6
    0b111000,   // 7
    0b111111,   // 8
    0b111101    // 9
}; 


/***** MAIN PROGRAM *****/
void main()
{
    char    digit;                  // digit to be displayed
    
    // Initialisation
    TRISA = 0;                      // configure PORTA and PORTC as all outputs
    TRISC = 0;
        
    // Main loop
    for (;;) {
        // display each digit from 0 to 9 for 1 sec
        for (digit = 0; digit < 10; digit++) {
            // display digit
            PORTA = pat7segA[digit];    // lookup port A and C patterns
            PORTC = pat7segC[digit];
        
            // delay 1 sec
            DelayS(1);
        }  
    }      
}
