/************************************************************************
*                                                                       *
*   Filename:      MC_L7-Count_7seg_x1-single-HTC.c                     *
*   Date:          16/11/09                                             *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     16F684                                               *
*   Compiler:      HI-TECH C PRO v9.65PL1 Lite                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: stdmacros-HTC.h     : provides DelayS()             *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 7, example 1b                                *
*                                                                       *
*   Demonstrates use of lookup tables to drive a 7-segment display      *
*                                                                       *
*   Single digit 7-segment display counts repeating 0 -> 9              *
*   1 second per count, with timing derived from int RC oscillator      *
*   (single pattern lookup array)                                       *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       RA2, RC0-5 = 7-segment display (common cathode)                 *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for delay functions
#include "stdmacros-HTC.h"      // DelayS() - delay in seconds


/***** CONFIGURATION *****/
//  ext reset, no code or data protect, no brownout detect,
//  no watchdog, power-up timer, int clock with I/O,
//  no failsafe clock monitor, two-speed start-up disabled 
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO & FCMDIS & IESODIS);


/***** LOOKUP TABLES *****/

// Lookup pattern for 7 segment display on ports A and C
const char pat7seg[10] = {
    // RC5:0,RA2 = ABCDEFG
    0b1111110,   // 0
    0b0110000,   // 1
    0b1101101,   // 2
    0b1111001,   // 3
    0b0110011,   // 4
    0b1011011,   // 5
    0b1011111,   // 6
    0b1110000,   // 7
    0b1111111,   // 8
    0b1111011    // 9
}; 


/***** MAIN PROGRAM *****/
void main()
{
    char    digit;                  // digit to be displayed
    
    // Initialisation
    TRISA = 0;                      // configure PORTA and PORTC as all outputs
    TRISC = 0;
    PORTA = 0;                      // make all PORTA pins low
        
    // Main loop
    for (;;) {
        // display each digit from 0 to 9 for 1 sec
        for (digit = 0; digit < 10; digit++) {
            // display digit
            RA2 = pat7seg[digit] & 0b0000001;   // extract pattern bits     
            PORTC = pat7seg[digit] >> 1;        // for each port
        
            // delay 1 sec
            DelayS(1);
        }  
    }      
}
