/************************************************************************
*                                                                       *
*   Filename:      MC_L8-ADC_4LEDs-HTC.c                                *
*   Date:          23/1/10                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     16F684                                               *
*   Compiler:      HI-TECH C v9.70 (Lite mode)                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 8, example 1                                 *
*                                                                       *
*   Demonstrates basic use of ADC                                       *
*                                                                       *
*   Continuously samples analog input, copying value to 4 x LEDs        *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       AN0     - voltage to be measured (e.g. pot output or LDR)       *
*       RC0-3   - output LEDs (RC3 is MSB)                              *
*                                                                       *
************************************************************************/

#include <htc.h>

#define _XTAL_FREQ  4000000     // oscillator frequency for __delay_us()


/***** CONFIGURATION *****/
//  ext reset, no code or data protect, no brownout detect,
//  no watchdog, power-up timer, int clock with I/O,
//  no failsafe clock monitor, two-speed start-up disabled 
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO & FCMDIS & IESODIS);


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    
    // configure ports
    TRISC = 0;                  // PORTC is all outputs
    ANSEL = 1<<0;               // AN0 (only) is analog
    CMCON0 = 7;                 // disable comparators  (CM = 7 -> both comparators off) 
    
    // configure ADC     
    ADCON1 = 0b00010000;
             //-001----          Tad = 8*Tosc (ADCS = 001) = 2.0 us (with Fosc = 4 MHz) 
    ADCON0 = 0b00000001;       
             //0-------          MSB of result in ADRESH<7> (ADFM = 0)
             //-0------          voltage reference is Vdd (VCFG = 0)
             //---000--          select channel AN0 (CHS = 000) 
             //-------1          turn ADC on (ADON = 1)
    
    // Main loop
    for (;;)
    {
        // sample analog input
        __delay_us(10);         // wait 10 us for acquisition time
        GODONE = 1;             // start conversion
        while (GODONE)          // wait until done
            ;
        
        // display result on 4 x LEDs
        PORTC = ADRESH >> 4;    // copy high four bits of result
                                //   to low nybble of output port
    }
}
