/************************************************************************
*                                                                       *
*   Filename:      MC_L8-ADC_Sleep-PCL.c                                *
*   Date:          24/1/10                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     16F684                                               *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: delay.h         : provides DelayUs()                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 8, example 2                                 *
*                                                                       *
*   Demonstrates use of ADC in sleep mode                               *
*                                                                       *
*   Continuously samples analog input, sleeping during conversion,      *
*   then copying high 4 bits of result to 4 x LEDs                      *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       AN0     - voltage to be measured (e.g. pot output or LDR)       *
*       RC0-3   - output LEDs (RC3 is MSB)                              *
*                                                                       *
************************************************************************/

#include <htc.h>

#define XTAL_FREQ   4MHZ        // oscillator frequency for DelayUs()
#include "delay.h"              // defines DelayUs()


/***** CONFIGURATION *****/
//  ext reset, no code or data protect, no brownout detect,
//  no watchdog, power-up timer, int clock with I/O,
//  no failsafe clock monitor, two-speed start-up disabled 
__CONFIG(MCLREN & UNPROTECT & BORDIS & WDTDIS & PWRTEN & INTIO & FCMDIS & IESODIS);


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    
    // configure ports
    TRISC = 0;                  // PORTC is all outputs
    ANSEL = 1<<0;               // AN0 (only) is analog
    CMCON0 = 7;                 // disable comparators  (CM = 7 -> both comparators off) 
    
    // configure ADC     
    ADCON1 = 0b00110000;
             //--11----          internal oscillator, Frc (ADCS = x11)
             //                   -> operation in sleep mode possible
    ADCON0 = 0b00000001;       
             //0-------          MSB of result in ADRESH<7> (ADFM = 0)
             //-0------          voltage reference is Vdd (VCFG = 0)
             //---000--          select channel AN0 (CHS = 000) 
             //-------1          turn ADC on (ADON = 1)
    
    // enable ADC interrupt (for wake on completion)
    ADIE = 1;                   // enable ADC interrupt
    PEIE = 1;                   // and peripheral interrupts
    
    // Main loop
    for (;;)
    {
        // sample analog input
        DelayUs(10);            // wait 10 us for acquisition time
        ADIF = 0;               // clear ADC interrupt flag
        GODONE = 1;             // start conversion

        SLEEP();                // sleep until done
        
        // display result on 4 x LEDs
        PORTC = ADRESH >> 4;    // copy high four bits of result
                                //   to low nybble of output port
    }
}
