/************************************************************************
*                                                                       *
*   Filename:      MC_L9-Flash_LED-32k_clock-HTC                        *
*   Date:          19/3/11                                              *
*   File Version:  1.1                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Midrange PIC                                         *
*   Processor:     16F684                                               *
*   Compiler:      HI-TECH C v9.81 (Lite mode)                          *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *                 
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Lesson 9, example 3                                 *
*                                                                       *
*   Demonstrates basic use of Timer1 LP oscillator                      *
*                                                                       *
*   LED flashes at 1 Hz (50% duty cycle), with timing derived           *
*   from 32.768 kHz crystal driven by Timer1 oscillator                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Pin assignments:                                                    *
*       RC0        - flashing LED                                       *
*       OSC1, OSC2 - 32.768 kHz crystal                                 *
*                                                                       *
************************************************************************/

#include <htc.h>


/***** CONFIGURATION *****/
//  ext reset, no code or data protect, no brownout detect,
//  no watchdog, power-up timer, int clock with I/O,
//  no failsafe clock monitor, two-speed start-up disabled 
__CONFIG(MCLRE_ON & CP_OFF & CPD_OFF & BOREN_OFF & WDTE_OFF & PWRTE_ON &
         FOSC_INTOSCIO & FCMEN_OFF & IESO_OFF);

// Pin assignments
#define nF_LED  0           // flashing LED on RC0


/***** GLOBAL VARIABLES *****/
unsigned char   sPORTC;                 // shadow copy of PORTC


/***** MAIN PROGRAM *****/
void main()
{
    // Initialisation
    
    // configure ports
    PORTC = 0;                      // start with PORTC clear (all LEDs off)
    sPORTC = 0;                     //   and update shadow
    TRISC = 0;                      // configure all PORTC pins as outputs
    
    // configure timers
    T1CON = 0b00001011;             // configure Timer1:
            //-0------                  gate disabled (TMR1GE = 0)
            //--00----                  prescale = 1 (T1CKPS = 00)
            //----1---                  LP oscillator enabled (T1OSCEN = 1)
            //------1-                  external clock (TMR1CS = 1)
            //-------1                  enable Timer1 (TMR1ON = 1)  
                                    //  -> increment TMR1 at 32.768 kHz

                 
    // Main loop  
    for (;;)
    {
        // TMR1<14> cycles at 1 Hz
        // so continually copy to LED
        if (TMR1 & 1<<14)                   // if TMR1<14> = 1
            sPORTC |= 1<<nF_LED;            //   turn on LED
        else                                // else
            sPORTC &= ~(1<<nF_LED);         //   turn it off
            
        // copy shadow register to port    
        PORTC = sPORTC;
    } 
}
