/************************************************************************
*                                                                       *
*   Filename:      dbmacros-PCL.h                                       *
*   Date:          27/1/08                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Baseline or Midrange PIC                             *
*   Processor:     any                                                  *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: none                                                *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Library of debounce macros                          *
*                                                                       *
*   DbnceHi - debounce switch, wait for high input                      *
*   DbnceLo - debounce switch, wait for low input                       *
*                                                                       *
************************************************************************/


#define DEBOUNCE 10*1000/256    // switch debounce count = 10ms/(256us/tick)

// DbnceHi()
//
// Debounce switch on given input pin
// Waits for switch input to be high continuously for 10 ms
//
// Uses: TMR0       Assumes: TMR0 running at 256 us/tick
//
#define DbnceHi(PIN) TMR0 = 0;                  /* reset timer              */ \
                     while (TMR0 < DEBOUNCE)    /* wait until debounce time */ \
                         if (PIN == 0)          /*   if input low,          */ \
                             TMR0 = 0           /*     restart wait         */


// DbnceLo()
//
// Debounce switch on given input pin
// Waits for switch input to be high continuously for 10 ms
//
// Uses: TMR0       Assumes: TMR0 running at 256 us/tick
//
#define DbnceLo(PIN) TMR0 = 0;                  /* reset timer              */ \
                     while (TMR0 < DEBOUNCE)    /* wait until debounce time */ \
                         if (PIN == 1)          /*   if input high,         */ \
                             TMR0 = 0           /*     restart wait         */

