/************************************************************************
*                                                                       *
*   Filename:      stdmacros-PCL.h                                      *
*   Date:          26/1/08                                              *
*   File Version:  1.0                                                  *
*                                                                       *
*   Author:        David Meiklejohn                                     *
*   Company:       Gooligum Electronics                                 *
*                                                                       *
*************************************************************************
*                                                                       *
*   Architecture:  Baseline or Midrange PIC                             *
*   Processor:     any                                                  *
*   Compiler:      HI-TECH PICC-Lite v9.60PL2                           *
*                                                                       *
*************************************************************************
*                                                                       *
*   Files required: delay.h, delay.c    : provides DelayMs()            *
*                                                                       *
*************************************************************************
*                                                                       *
*   Description:    Library of useful macros                            *
*                                                                       *
*   DelayS() - delay in seconds (wrapper for DelayMs function)          *
*   DbnceHi - debounce switch, wait for high input                      *
*   DbnceLo - debounce switch, wait for low input                       *
*                                                                       *
************************************************************************/


/***** DELAY MACROS *****/

// DelayS()
//
// Delay in seconds (max 25.5)
//
// Calls: DelayMs() (defined in delay.h)
//
#include "delay.h"
#define DelayS(T) {unsigned char i; for (i=0; i<T*10; i++) DelayMs(100);}


/***** DEBOUNCE MACROS *****/

#define DEBOUNCE 10*1000/256    // switch debounce count = 10ms/(256us/tick)

// DbnceHi()
//
// Debounce switch on given input pin
// Waits for switch input to be high continuously for 10ms
//
// Uses: TMR0       Assumes: TMR0 running at 256us/tick
//
#define DbnceHi(PIN) TMR0 = 0;                  /* reset timer              */ \
                     while (TMR0 < DEBOUNCE)    /* wait until debounce time */ \
                         if (PIN == 0)          /*   if input low,          */ \
                             TMR0 = 0           /*     restart wait         */


// DbnceLo()
//
// Debounce switch on given input pin
// Waits for switch input to be high continuously for 10ms
//
// Uses: TMR0       Assumes: TMR0 running at 256us/tick
//
#define DbnceLo(PIN) TMR0 = 0;                  /* reset timer              */ \
                     while (TMR0 < DEBOUNCE)    /* wait until debounce time */ \
                         if (PIN == 1)          /*   if input high,         */ \
                             TMR0 = 0           /*     restart wait         */
